# Disclaimer

Blueprints is an open source engineering tool that continues to benefit from the collaboration of many contributors. Although efforts have been made to ensure the that relevant engineering theories have been correctly implemented, it remains the user's responsibility to confirm and accept the output. Refer to the [license](LICENSE) for clarification of the conditions of use.

By using the Blueprints package, you are agreeing to the following:

## 1. Usage Risk

The usage (i.e. downloading, installing, running, modifying the code, or some or all of the above) of Blueprints is entirely at your own risk as a user and/or contributor. All maintainers and contributors to Blueprints are not responsible for and cannot be held responsible or liable for any direct or indirect damages, injuries, death, faults, mistakes, or omissions that result from the usage of the package.

## 2. Adherence to Laws and Regulations

At all times, the user is fully responsible for the adherence to (local) laws and regulations. It is the user's responsibility to ensure that their use of Blueprints complies with all relevant legal and regulatory requirements.

## 3. Outdated Results

Results may be outdated due to circumstances, changes in rules and regulations, and/or changes in the codes and/or national annexes. Users should always verify the results and not solely rely on the output from Blueprints.

## 4. Agreement to Terms

When using Blueprints, you agree to the terms and conditions of the [license](LICENSE) and this disclaimer.

## 5. Warranties

Blueprints is provided as is without any warranties of any kind, either expressed or implied.

---

Please note that this disclaimer is intended to be as broad and inclusive as permitted by the law of the jurisdiction in which you reside. If any portion of this disclaimer is held invalid, the remainder shall continue in full legal force and effect.